
import React, { Suspense } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { AuthProvider } from "@/contexts/AuthContext";
import { PetProvider } from "@/contexts/PetContext";
import { ThemeProvider } from "@/contexts/ThemeContext";
import RouteGuard from "@/components/RouteGuard";
import TrialGuard from "@/components/guards/TrialGuard";

// Lazy load all pages for better performance
const Index = React.lazy(() => import("./pages/Index"));
const Auth = React.lazy(() => import("./pages/Auth"));
const Pets = React.lazy(() => import("./pages/Pets"));
const AddPet = React.lazy(() => import("./pages/AddPet"));
const PetProfile = React.lazy(() => import("./pages/PetProfile"));

const Community = React.lazy(() => import("./pages/Community"));
const Copilot = React.lazy(() => import("./pages/Copilot"));
const Marketplace = React.lazy(() => import("./pages/Marketplace"));
const Profile = React.lazy(() => import("./pages/Profile"));
const Subscription = React.lazy(() => import("./pages/Subscription"));
const Contact = React.lazy(() => import("./pages/Contact"));
const PrivacyPolicy = React.lazy(() => import("./pages/PrivacyPolicy"));
const TermsAndConditions = React.lazy(() => import("./pages/TermsAndConditions"));
const Disclaimer = React.lazy(() => import("./pages/Disclaimer"));
const RefundPolicy = React.lazy(() => import("./pages/RefundPolicy"));
const CookiePolicy = React.lazy(() => import("./pages/CookiePolicy"));
const ShippingPolicy = React.lazy(() => import("./pages/ShippingPolicy"));
const PublicHome = React.lazy(() => import("./pages/PublicHome"));
const NotFound = React.lazy(() => import("./pages/NotFound"));

// Keep critical components as regular imports for faster initial load
import PublicHomeRedirect from "./components/PublicHomeRedirect";

const queryClient = new QueryClient();

// Wrapper component for routes that need PetProvider
const PetContextWrapper = ({ children }: { children: React.ReactNode }) => (
  <PetProvider>{children}</PetProvider>
);

const App = () => (
  <QueryClientProvider client={queryClient}>
    <ThemeProvider>
      <TooltipProvider>
        <Toaster />
        <Sonner />
        <BrowserRouter>
          <AuthProvider>
            <RouteGuard>
              <Suspense fallback={<div className="flex items-center justify-center h-screen">Loading...</div>}>
                <Routes>
                  <Route path="/auth" element={<Auth />} />
                  <Route path="/public" element={<PublicHome />} />
                  <Route path="/" element={<PublicHomeRedirect />} />
                  <Route path="/app" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <Index />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/pets" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <Pets />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/pets/add" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <AddPet />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/pets/:petId" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <PetProfile />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/community" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <Community />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/copilot" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <Copilot />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/marketplace" element={
                    <PetContextWrapper>
                      <TrialGuard>
                        <Marketplace />
                      </TrialGuard>
                    </PetContextWrapper>
                  } />
                  <Route path="/profile" element={
                    <PetContextWrapper>
                      <Profile />
                    </PetContextWrapper>
                  } />
                  <Route path="/subscription" element={
                    <PetContextWrapper>
                      <Subscription />
                    </PetContextWrapper>
                  } />
                  <Route path="/contact" element={<Contact />} />
                  <Route path="/privacy-policy" element={<PrivacyPolicy />} />
                  <Route path="/terms-and-conditions" element={<TermsAndConditions />} />
                  <Route path="/disclaimer" element={<Disclaimer />} />
                  <Route path="/refund-policy" element={<RefundPolicy />} />
                  <Route path="/cookie-policy" element={<CookiePolicy />} />
                  <Route path="/shipping-policy" element={<ShippingPolicy />} />
                  <Route path="*" element={<NotFound />} />
                </Routes>
              </Suspense>
            </RouteGuard>
          </AuthProvider>
        </BrowserRouter>
      </TooltipProvider>
    </ThemeProvider>
  </QueryClientProvider>
);

export default App;
